@@ -75,6 +75,10 @@ will always include, in addition to the exception’s main message:
 B<IMPORTANT:> For security purposes, take care not to expose any function
 arguments that might contain sensitive information (e.g., passwords).
 
+Note that, in pre-5.16 Perls, this writes to the C<@DB::args> global.
+(That shouldn’t affect you, but it’s interaction with the environment, so
+better documented than not.)
+
 =item * Propagations
 
 =back
@@ -125,7 +129,7 @@ sub _new {
     return bless [ $string, \%attrs ], $class;
 }
 
-=head2 I<OBJ>->get_messaage()
+=head2 I<OBJ>->get_message()
 
 Return the exception’s main MESSAGE.
 This is useful for contexts where you want to encapsulate the error
@@ -194,7 +198,7 @@ sub new {
 
     my $self = $class->_new(@args);
 
-    $CALL_STACK{$self->_get_strval()} = [ _get_call_stack(2) ];
+    $CALL_STACK{$self->_get_strval()} = [ _get_printable_call_stack(2) ];
 
     return $self;
 }
@@ -219,7 +223,12 @@ sub _check_overload {
 
     $_OVERLOADED{$class} ||= eval qq{
         package $class;
-        use overload (q<""> => __PACKAGE__->can('__spew'));
+
+        use overload (
+            q<""> => __PACKAGE__->can('__spew'),
+            bool => __PACKAGE__->can('_TRUE'),
+        );
+
         1;
     };
 
@@ -241,7 +250,7 @@ sub _get_strval {
     return q<> . $self;
 }
 
-sub _get_call_stack {
+sub _get_printable_call_stack {
     my ($level) = @_;
 
     my @stack;
@@ -255,7 +264,7 @@ sub _get_call_stack {
         my ($pkg) = ($call[0] =~ m<(.+)::>);
 
         if (!$pkg || !$pkg->isa(__PACKAGE__)) {
-            push @call, \@DB::args;
+            push @call, [ map { X::Tiny::Base::_arg_to_printable() } @DB::args ];  #need to copy the array
             push @stack, \@call;
         }
 
@@ -265,13 +274,26 @@ sub _get_call_stack {
     return @stack;
 }
 
+sub _arg_to_printable {
+
+    # Oof. In order to avoid warn()ing on undefined values
+    # (and to distinguish '' from undef) we now quote scalars.
+    ref() ? "$_" : !defined() ? 'undef' : do {
+        my $copy = $_;
+        $copy =~ s<'><\\'>g;
+        "'$copy'";
+    };
+}
+
+use constant _TRUE => 1;
+
 sub __spew {
     my ($self) = @_;
 
     my $spew = $self->to_string();
 
     if ( rindex($spew, $/) != (length($spew) - length($/)) ) {
-        my $args;
+        my ($args);
         $spew .= $/ . join( q<>, map {
             $args = join(', ', @{ $_->[3] } );
             "\t==> $_->[0]($args) (called in $_->[1] at line $_->[2])$/"
